==> ja-hns-2.10.1.tgz: share/hns/public_html/diary/lib/HNS/System.pm <==
# $Id: System.pm,v 1.12 2000/08/26 12:25:09 kenji Exp $
package HNS::System;

################################################################
# system variable

$Title  = "HNS: hoge's diary";
$UserMail = 'hoge@foo.bar.jp';
$DiaryDir = "../../diary";
$MyDiaryURI = "http://www.foo.bar.jp/~hoge/diary/"; #"%MYDIARYURI%"; 
$IncludeDir = "./"; 

$DefaultMax = 5;
$StartYear = 1998;
$Theme = "japanese";
$ImgWidthMaxSize = 300;

$RefererLog = "ON";
$LinkLog = "ON";
$CookieFlag = "ON";
$AdminCookieFlag = "ON";
$CookieExpires = '+1M';
$TZ = 9;

$IgnoreReversed = "OFF";

$FNCountStyle = 1;	# 1 -> each day, 0 -> each section
$AlwaysReverse = "OFF";

$NewReverse = 0;        # 0 -> normal, 1 -> reverse

$LessOutput = 0;	# 1 -> less ouput, 0 -> normal (default)

# error message
$Error{404} = qq(Status: 404 Not Found\r
Content-Type: text/html\r
\r
<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html><head>
<title>404 Not Found</title>
</head><body>
<h1>Not Found</h1>
The requested URL $ENV{'REQUEST_URI'} was not found on this server.
<hr>
<address>Apache Server at $ENV{'SERVER_NAME'} Port $ENV{'SERVER_PORT'}</address>
</body></html>
);

$Error{403} = qq(Status: 403 Forbidden\r
Content-Type: text/html\r
\r
<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html><head>
<title>403 Forbidden</title>
</head><body>
<h1>Forbidden</h1>
You don't have permission to access $ENV{'REQUEST_URI'}
on this server.
<hr>
<address>Apache Server at $ENV{'SERVER_NAME'} Port $ENV{'SERVER_PORT'}</address>
</body></html>
);

1;

==> ja-hns-2.10.3.tgz: share/hns/public_html/diary/lib/HNS/System.pm <==
# $Id: System.pm,v 1.12.2.1 2002/03/28 16:10:09 kenji Exp $
package HNS::System;

################################################################
# system variable

$Title  = "HNS: hoge's diary";
$UserMail = 'hoge@foo.bar.jp';
$DiaryDir = "../../diary";
$MyDiaryURI = "http://www.foo.bar.jp/~hoge/diary/"; #"%MYDIARYURI%"; 
$IncludeDir = "./"; 

$DefaultMax = 5;
$StartYear = 1998;
$Theme = "japanese";
$ImgWidthMaxSize = 300;

$RefererLog = "ON";
$LinkLog = "ON";
$CookieFlag = "ON";
$AdminCookieFlag = "ON";
$CookieExpires = '+1M';
$TZ = 9;

$IgnoreReversed = "OFF";

$FNCountStyle = 1;	# 1 -> each day, 0 -> each section
$AlwaysReverse = "OFF";

$NewReverse = 0;        # 0 -> normal, 1 -> reverse

$LessOutput = 0;	# 1 -> less ouput, 0 -> normal (default)

# error message
use CGI::Tools;
$ruri = CGI::Tools::Escape($ENV{'REQUEST_URI'});
$Error{404} = qq(Status: 404 Not Found\r
Content-Type: text/html\r
\r
<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html><head>
<title>404 Not Found</title>
</head><body>
<h1>Not Found</h1>
The requested URL $ruri was not found on this server.
<hr>
<address>Apache Server at $ENV{'SERVER_NAME'} Port $ENV{'SERVER_PORT'}</address>
</body></html>
);

$Error{403} = qq(Status: 403 Forbidden\r
Content-Type: text/html\r
\r
<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
<html><head>
<title>403 Forbidden</title>
</head><body>
<h1>Forbidden</h1>
You don't have permission to access $ruri
on this server.
<hr>
<address>Apache Server at $ENV{'SERVER_NAME'} Port $ENV{'SERVER_PORT'}</address>
</body></html>
);

1;
